@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright 2011 Tomo Krajina
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,10 +12,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from typing import IO, Union, Optional, AnyStr
 
-__version__ = '1.3.5'
+from . import gpx as mod_gpx
 
-def parse(xml_or_file, version = None):
+__version__ = '1.4.0'
+
+def parse(xml_or_file: Union[AnyStr, IO[str]], version: Optional[str] = None) -> mod_gpx.GPX:
     """
     Parse xml (string) or file object. This is just an wrapper for
     GPXParser.parse() function.
